@@ -1,5 +1,6 @@
 #include <string.h>
 #include <stdlib.h>
+#include <signal.h>
 #include <time.h>
 #include <glib.h>
 #include <dbus/dbus-glib.h>
@@ -50,7 +51,8 @@ static void sig_display_status(DBusGProxy *proxy, const char *status, gpointer u
 	 * in the two ButtonPress events being received before the display_status==on
 	 * event.  Check here if that's the case.
 	 */
-	if (app->display_on && app->press_count > 1 && time(NULL) - app->last_press <= 1)
+	if (app->mode_locked && app->display_on && app->press_count > 1 &&
+			time(NULL) - app->last_press <= 1)
 		speak_time(app);
 }
 
@@ -183,6 +185,7 @@ int main(int argc, char *argv[])
 
 	g_debug("init");
 	memset(&app, 0, sizeof(app));
+	signal(SIGCHLD, SIG_IGN);
 
 	g_type_init();
 	loop = g_main_loop_new(NULL, FALSE);
